@@ -1,19 +1,5 @@
 package App::CharmKit::Command::lint;
-
-=head1 NAME
-
-App::CharmKit::Command::lint - charm linter
-
-=head1 SYNOPSIS
-
-  $ charmkit lint
-
-=head1 DESCRIPTION
-
-This will try to perform an indepth charm proof check so that uploaded charms
-may receive quicker turnaround times during review process.
-
-=cut
+$App::CharmKit::Command::lint::VERSION = '2.04';
 
 use strict;
 use warnings;
@@ -33,3 +19,32 @@ sub execute($self, $opt, $args) {
 
 1;
 
+__END__
+
+=pod
+
+=head1 NAME
+
+App::CharmKit::Command::lint
+
+=head1 SYNOPSIS
+
+  $ charmkit lint
+
+=head1 DESCRIPTION
+
+This will try to perform an indepth charm proof check so that uploaded charms
+may receive quicker turnaround times during review process.
+
+=head1 AUTHOR
+
+Adam Stokes <adamjs@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2016 by Adam Stokes.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
