@@ -1,5 +1,5 @@
 package App::CharmKit::Role::Lint;
-
+$App::CharmKit::Role::Lint::VERSION = '2.04';
 use strict;
 use warnings;
 use YAML::Tiny;
@@ -330,12 +330,13 @@ sub lint_print($self, $item, $error) {
 
 1;
 
-
 __END__
 
+=pod
+
 =head1 NAME
 
-App::CharmKit::Role::Lint - linter methods
+App::CharmKit::Role::Lint
 
 =head1 SYNOPSIS
 
@@ -367,5 +368,15 @@ The format for rules is as follows:
         - pattern: '^options:\s*\n'
           error: 'ERR_INVALID_COPYRIGHT'
 
-=cut
+=head1 AUTHOR
 
+Adam Stokes <adamjs@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2016 by Adam Stokes.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
