@@ -1,26 +1,8 @@
 package charm;
+$charm::VERSION = '2.04';
+# ABSTRACT: DSL entrypoint
 
-=head1 NAME
 
-charm - sugary charm entrypoint
-
-=head1 SYNOPSIS
-
-  use charm;
-
-  run "juju-log Starting install";
-  my $output = run 'ls /tmp';
-  print($output);
-
-=cut
-
-=head1 DESCRIPTION
-
-Exposing helper subs from various packages that would be useful in writing
-charm hooks. Including but not limited too strict, warnings, Path::Tiny, Rex, Mojolicious,
-etc ..
-
-=cut
 
 use strict;
 use warnings;
@@ -48,8 +30,6 @@ use POSIX;
 use FindBin;
 use lib "$FindBin::Bin/../lib";
 
-our $VERSION = '2.03';
-
 sub import {
     my $target = caller;
     my $class  = shift;
@@ -91,3 +71,38 @@ sub import {
 
 
 1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+charm - DSL entrypoint
+
+=head1 SYNOPSIS
+
+  use charm;
+
+  run "juju-log Starting install";
+  my $output = run 'ls /tmp';
+  print($output);
+
+=head1 DESCRIPTION
+
+Exposing helper subs from various packages that would be useful in writing
+charm hooks. Including but not limited too strict, warnings, Path::Tiny, Rex, Mojolicious,
+etc ..
+
+=head1 AUTHOR
+
+Adam Stokes <adamjs@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2016 by Adam Stokes.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
